import {Image, PageContainer, Progress, View} from "@tarojs/components";
import Taro from "@tarojs/taro";
import styles from './curHistory.module.scss'
import {useState} from "react";
import {userApi} from "@/api";
import {formatDateTime, formatMinute} from "@/utils/time";

const CurHistory = () => {
  const [show, setShow] = useState(false)
  const {course_id, name} = Taro.getCurrentInstance().preloadData as { course_id: number, name: string }
  const [data, setData] = useState<userRecord[]>([])

  Taro.useLoad(() => {
    Taro.setNavigationBarTitle({title: name})
    userApi.courseRecord(course_id).then(res => {
      setData(Object.values(res))
    })
  })

  function setHour() {
    setShow(true)
  }

  return (
    <View>
      <View className={styles.cur}>
        <Image src={''} mode='aspectFit'/>
        <View>{name}</View>
      </View>


      <View className={styles.record}>

        {
          data.map(d => <View onClick={() => setHour()} className={styles.recordItem}>
            <View>{formatDateTime(new Date(d.start_at), "MM-dd HH:ss")} - {formatDateTime(new Date(d.end_at), "MM-dd HH:ss")}</View>
            <View>观看：{formatMinute(d.duration)}</View>
            <Progress
              percent={d.duration}
              showInfo
              borderRadius={10}
              active
              strokeWidth={10}
              color={'#45D4A8'}
            />
          </View>)
        }


      </View>

      <PageContainer
        show={show}
        round
        onAfterLeave={() => setShow(false)}>
        {show && <View className={styles.hourRecord}>
          <View>
            <View onClick={() => setHour()} className={styles.recordItem}>
              <View>2023-6-19</View>
              <Progress
                percent={10}
                showInfo
                borderRadius={10}
                active
                strokeWidth={10}
                color={'#45D4A8'}
              />
            </View>
          </View>
        </View>}
      </PageContainer>
    </View>
  )
}

export default CurHistory
